<?php

namespace App\Traits;

use App\Entity\Abstraction\BaseEntity;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\JsonResponse;

trait JsonResponseTrait {
    protected function ok($data, $code = Response::HTTP_OK, $headers = []) {
        return $this->response($data, $code, $headers);
    }

    protected function created($data, $code = Response::HTTP_CREATED, $headers = []) {
        return $this->response($data, $code, $headers);
    }

    protected function notAcceptable($data, $code = Response::HTTP_NOT_ACCEPTABLE, $headers = []) {
        return $this->response([ 'error' => 'Not acceptable', 'data' => $data], $code, $headers);
    }

    protected function unauthorized($data, $code = Response::HTTP_UNAUTHORIZED, $headers = []) {
        return $this->response([ 'error' => 'Unauthorized', 'data' => $data], $code, $headers);
    }

    protected function response($data, $code = Response::HTTP_OK, $headers = []) {

        if ($data instanceof BaseEntity) {
            $data = $data->toArray();
        }

        if (is_array($data)) {
            foreach ($data as $key => $value) {
                if ($value instanceof BaseEntity) {
                    $data[$key] = $value->toArray();
                }
            }
        }

        return new JsonResponse($data, $code, $headers);
    }
}