import { Injectable } from '@angular/core';
import { Subject } from 'rxjs';
import { BrowserStorageService } from '../browser-storage/browser-storage.service';

export class ThemeDefinition {
    name: string;
    isDark: boolean;
    isDefault: boolean;
    relatedTheme: string | undefined;
}
@Injectable()
export class ThemeService {
    private theme: string;
    themeChange = new Subject<string>();

    constructor(
        browserStorageService: BrowserStorageService
    ) {
        this.themeChange.subscribe(theme => {
            this.theme = theme;
            browserStorageService.setItem('current-theme', theme);
        });
        let userTheme = browserStorageService.getItem('current-theme');
        if (!userTheme) {
            userTheme = window.matchMedia('(prefers-color-scheme: dark)').matches ? 'dark' : 'light';
        }
        this.setTheme(userTheme);
    }

    getTheme(): string {
        return this.theme;
    }

    setTheme(theme: string): void {
        if (theme !== this.theme) {
            this.themeChange.next(theme);
            document.getElementById('current-theme').setAttribute('href', `/${theme}.css`);
        }
    }

    getThemes(): ThemeDefinition[] {
        return [
            {
                name: 'light',
                isDark: false,
                isDefault: true,
                relatedTheme: 'dark',
            },
            {
                name: 'dark',
                isDark: true,
                isDefault: true,
                relatedTheme: 'light',
            }
        ];
    }
}
